[![Build Status](https://secure.travis-ci.org/freelan-developers/teapot.png)](https://secure.travis-ci.org/freelan-developers/teapot)

teapot
=========

A tool to handle third-party softwares in projects.

What is teapot ?
-------------------

teapot is a Python library, and its associated command-line tool, that eases fetching and compilation of third-party softwares.

How to use it ?
---------------

*teapot*'s documentation can be reached at [http://teapot-builder.readthedocs.org/en/latest/].

Licensing
---------

teapot is licensed under the [MIT license](http://opensource.org/licenses/MIT).
